@@ -12,7 +12,7 @@ class A3Behavior extends Behavior {
     A3BranchGroup topGroup;
     TransformGroup transGroup;
     Transform3D t;
-    A3CanvasInterface canvas = null;
+    A3VirtualUniverse universe = null;
     boolean isInterpolate = false;
     boolean autoDirectionControl = false;
     double nextS = 1.0;
@@ -33,8 +33,8 @@ class A3Behavior extends Behavior {
         transGroup.addChild(this);
         topGroup.addChild(transGroup);
     }
-    void setA3CanvasInterface(A3CanvasInterface c) {
-        canvas = c;
+    void setA3VirtualUniverse(A3VirtualUniverse u) {
+        universe = u;
     }
     void setNode(Node n) {
         transGroup.addChild(n);
@@ -49,12 +49,12 @@ class A3Behavior extends Behavior {
     }
     @SuppressWarnings("unchecked")
     public void processStimulus(Enumeration criteria) {
-        if (canvas==null) {
+        if (universe==null) {
             WakeupOnElapsedTime w = new WakeupOnElapsedTime(elapsedTime);
             wakeupOn(w);
         } else {
             WakeupOnBehaviorPost w = null;
-            w = new WakeupOnBehaviorPost(canvas.getTimerBehavior(),1);
+            w = new WakeupOnBehaviorPost(universe.getTimerBehavior(),1);
             wakeupOn(w);
         }
 
@@ -211,7 +211,7 @@ class A3Behavior extends Behavior {
             tmpV.sub(nextV,nowV);
             double d = tmpV.length();
             double t;
-            if (canvas!=null) {
+            if (universe!=null) {
                 t = TimerBehavior.elapsedTime/1000.0;
             } else {
                 t = elapsedTime/1000.0;
