@@ -17,8 +17,15 @@ class A3Label implements Component2D {
     }
     public void paint(Graphics2D g,A3CanvasInterface canvas) {
         Vector3d v = a3.getLoc();
-        Point p = canvas.virtualCSToCanvas(new Point3d(v.x+offsetX,
-                v.y+offsetY,v.z+offsetZ));
+        Vector3d vv = new Vector3d(offsetX,offsetY,offsetZ);
+        vv.scale(a3.getScale());
+        Vector3d p3d = new Vector3d(v.x+vv.x,v.y+vv.y,v.z+vv.z);
+        Point p = null;
+        if (a3.lockedA3==false) {
+            p = canvas.virtualCSToCanvas(new Point3d(p3d));
+        } else {
+            p = canvas.physicalCSToCanvas(new Point3d(p3d));
+        }
         if ((width==0)||(height==0)) {
             FontMetrics fm = g.getFontMetrics();
             width = fm.stringWidth(label)+4;
