@@ -16,12 +16,14 @@ public abstract class A3Object {
 
 
     A3Behavior behavior = null;
-    A3CanvasInterface canvas = null;
+    Scene scene = null;
     A3Label label = null;
     A3Balloon balloon = null;
     A3Selected selected = null;
     boolean isSelected = false;
     Object userData = null;
+    boolean lockedA3 = false;
+    boolean pickable = true;
     /**
      * 座標系の上を指定するための列挙型。
      */
@@ -50,6 +52,7 @@ public abstract class A3Object {
         if (d.balloon!=null)
             setBalloon(d.balloon);
         upperDirection = d.upperDirection;
+        pickable = d.pickable;
     }
 
     /**
@@ -148,17 +151,17 @@ public abstract class A3Object {
         setBalloon(d.balloon);
     }
 
-    void setA3CanvasInterface(A3CanvasInterface c) {
-        canvas = c;
-        behavior.setA3CanvasInterface(c);
-        if (canvas==null)
+    void setScene(Scene s) {
+        scene = s;
+        behavior.setA3VirtualUniverse(s.universe);
+        if (scene==null)
             return;
         if (label!=null)
-            canvas.add(label);
+            scene.add(label);
         if (balloon!=null)
-            canvas.add(balloon);
+            scene.add(balloon);
         if (selected!=null)
-            canvas.add(selected);
+            scene.add(selected);
     }
 
     final A3BranchGroup getA3BranchGroup() {
@@ -370,13 +373,13 @@ public abstract class A3Object {
      * このオブジェクトのリソースを開放します。
      */
     public final void dispose() {
-        if (canvas!=null) {
+        if (scene!=null) {
             if (label!=null)
-                canvas.del(label);
+                scene.del(label);
             if (balloon!=null)
-                canvas.del(balloon);
+                scene.del(balloon);
             if (selected!=null)
-                canvas.del(selected);
+                scene.del(selected);
         }
     }
 
@@ -389,17 +392,17 @@ public abstract class A3Object {
         if (l!=null) {
             if (label!=null) {
                 label.setString(l);
-                if (canvas!=null)
-                    canvas.add(label);
+                if (scene!=null)
+                    scene.add(label);
             } else {
                 label = new A3Label(l,this);
-                if (canvas!=null)
-                    canvas.add(label);
+                if (scene!=null)
+                    scene.add(label);
             }
         } else {
             if (label!=null) {
-                if (canvas!=null)
-                    canvas.del(label);
+                if (scene!=null)
+                    scene.del(label);
             }
         }
     }
@@ -415,18 +418,18 @@ public abstract class A3Object {
             if (label!=null) {
                 label.setString(l);
                 label.setOffset(x,y,z);
-                if (canvas!=null)
-                    canvas.add(label);
+                if (scene!=null)
+                    scene.add(label);
             } else {
                 label = new A3Label(l,this);
                 label.setOffset(x,y,z);
-                if (canvas!=null)
-                    canvas.add(label);
+                if (scene!=null)
+                    scene.add(label);
             }
         } else {
             if (label!=null) {
-                if (canvas!=null)
-                    canvas.del(label);
+                if (scene!=null)
+                    scene.del(label);
             }
         }
     }
@@ -439,17 +442,17 @@ public abstract class A3Object {
         if (s!=null) {
             if (balloon!=null) {
                 balloon.setString(s);
-                if (canvas!=null)
-                    canvas.add(balloon);
+                if (scene!=null)
+                    scene.add(balloon);
             } else {
                 balloon = new A3Balloon(s,this);
-                if (canvas!=null)
-                    canvas.add(balloon);
+                if (scene!=null)
+                    scene.add(balloon);
             }
         } else {
             if (balloon!=null) {
-                if (canvas!=null)
-                    canvas.del(balloon);
+                if (scene!=null)
+                    scene.del(balloon);
             }
         }
     }
@@ -464,18 +467,18 @@ public abstract class A3Object {
             if (balloon!=null) {
                 balloon.setString(s);
                 balloon.setOffset(x,y,z);
-                if (canvas!=null)
-                    canvas.add(balloon);
+                if (scene!=null)
+                    scene.add(balloon);
             } else {
                 balloon = new A3Balloon(s,this);
                 balloon.setOffset(x,y,z);
-                if (canvas!=null)
-                    canvas.add(balloon);
+                if (scene!=null)
+                    scene.add(balloon);
             }
         } else {
             if (balloon!=null) {
-                if (canvas!=null)
-                    canvas.del(balloon);
+                if (scene!=null)
+                    scene.del(balloon);
             }
         }
     }
@@ -488,16 +491,16 @@ public abstract class A3Object {
         isSelected = b;
         if (b) {
             if (selected!=null) {
-                if (canvas!=null)
-                    canvas.add(selected);
+                if (scene!=null)
+                    scene.add(selected);
             } else {
                 selected =new A3Selected(this);
-                if (canvas!=null)
-                    canvas.add(selected);
+                if (scene!=null)
+                    scene.add(selected);
             }
         } else {
-            if (canvas!=null)
-                canvas.del(selected);
+            if (scene!=null)
+                scene.del(selected);
         }
     }
 
@@ -537,4 +540,17 @@ public abstract class A3Object {
     public final double getSpeed() {
         return behavior.getSpeed();
     }
+    /**
+     * ピッキングできるかどうかを設定するメソッドです。
+     * デフォルトはtrueです。
+     */
+    public void setPickable(boolean b) {
+        pickable = b;
+    }
+    /**
+     * ピッキングできるかどうかを調べるメソッドです。
+     */
+    public boolean getPickable() {
+        return pickable;
+    }
 }
