@@ -65,7 +65,7 @@ class Action3DData {
 
     Action actions[];
     String actionNames[];
-    HashMap<String,SharedGroup> shapes;
+    HashMap<String,ShapeAndBF> shapes;
     HashMap<String,Motion> motions;
     HashMap<String,MediaContainer> sounds;
     BranchGroup allActionBranchGroup;
@@ -101,7 +101,6 @@ class Action3DData {
         Motion motion;
         HashMap<String,TransformGroup> tgMap;
 
-
         Action copy() {
             Action ret = new Action();
             ret.actionNo = actionNo;
@@ -160,8 +159,9 @@ class Action3DData {
             Part p = pHash.get(rootBoneName);
             if (p!=null) {
                 Node n = null;
+                ShapeAndBF sabf = shapes.get(p.fileName);
                 if ((p.rotationXYZ==null)&&(p.offsetXYZ==null)&&(p.scale==1.0)) {
-                    n = new Link(shapes.get(p.fileName));
+                    n = new Link(sabf.sg);
                 } else {
                     Transform3D t9a = new Transform3D();
                     Transform3D t9b = new Transform3D();
@@ -183,10 +183,17 @@ class Action3DData {
                         t9a.mul(t9b);
                     }
                     TransformGroup tg9 = new TransformGroup(t9a);
-                    tg9.addChild(new Link(shapes.get(p.fileName)));
+                    tg9.addChild(new Link(sabf.sg));
                     n = tg9;
                 }
                 tg.addChild(n);
+
+                if (sabf.b!=null)
+                    for (int i=0;i<sabf.b.length;i++) 
+                        rootGroup.addChild(sabf.b[i].cloneNode(false));
+                if (sabf.f!=null)
+                    for (int i=0;i<sabf.f.length;i++) 
+                        rootGroup.addChild(sabf.f[i].cloneNode(false));
             }
             tgMap.put(rootBoneName,tg);
             construct(tg,rootBoneName,tgMap);
@@ -226,8 +233,9 @@ class Action3DData {
                 parent.addChild(tg);
                 Part p = pHash.get(children[i]);
                 if (p!=null) {
+                    ShapeAndBF sabf = shapes.get(p.fileName);
                     if ((p.rotationXYZ==null)&&(p.offsetXYZ==null)&&(p.scale==1.0)) {
-                        tg.addChild(new Link(shapes.get(p.fileName)));
+                        tg.addChild(new Link(sabf.sg));
                     } else {
                         Transform3D t9a = new Transform3D();
                         Transform3D t9b = new Transform3D();
@@ -249,9 +257,15 @@ class Action3DData {
                             t9a.mul(t9b);
                         }
                         TransformGroup tg9 = new TransformGroup(t9a);
-                        tg9.addChild(new Link(shapes.get(p.fileName)));
+                        tg9.addChild(new Link(sabf.sg));
                         tg.addChild(tg9);
                     }
+                    if (sabf.b!=null)
+                        for (int j=0;j<sabf.b.length;j++) 
+                            rootGroup.addChild(sabf.b[j].cloneNode(false));
+                    if (sabf.f!=null)
+                        for (int j=0;j<sabf.f.length;j++) 
+                            rootGroup.addChild(sabf.f[j].cloneNode(false));
                 }
                 tgMap.put(children[i],tg);
                 construct(tg,children[i],tgMap);
@@ -332,7 +346,7 @@ class Action3DData {
         for (int i=0;i<actions.length;i++) {
             ret.actions[i] = actions[i].copy();
         }
-        ret.shapes = new HashMap<String,SharedGroup>(shapes);
+        ret.shapes = new HashMap<String,ShapeAndBF>(shapes);
         ret.motions = new HashMap<String,Motion>(motions);
         ret.sounds = new HashMap<String,MediaContainer>(sounds);
         return ret;
@@ -347,12 +361,32 @@ class Action3DData {
         Unmarshaller u = jc.createUnmarshaller();
         A3 a3 = null;
         try {
-            URL cURL = new URL("x-rzip:"+url.toString()+"!/CATALOG.XML");
+            URL cURL = null;
+            if (url.getProtocol().equals("file")) {
+                File f = new File(url.toURI());
+                if (f.isDirectory()) {
+                    cURL = new URL(url.toString()+"/CATALOG.XML");
+                } else {
+                    cURL = new URL("x-rzip:"+url.toString()+"!/CATALOG.XML");
+                }
+            } else {
+                cURL = new URL("x-rzip:"+url.toString()+"!/CATALOG.XML");
+            }
             a3 = (A3)u.unmarshal(cURL.openStream());
         } catch(Exception e) {
             e.printStackTrace();
             try {
-                URL cURL = new URL("x-rzip:"+url.toString()+"!/catalog.xml");
+                URL cURL = null;
+                if (url.getProtocol().equals("file")) {
+                    File f = new File(url.toURI());
+                    if (f.isDirectory()) {
+                        cURL = new URL(url.toString()+"/catalog.xml");
+                    } else {
+                        cURL = new URL("x-rzip:"+url.toString()+"!/catalog.xml");
+                    }
+                } else {
+                    cURL = new URL("x-rzip:"+url.toString()+"!/catalog.xml");
+                }
                 a3 = (A3)u.unmarshal(cURL.openStream());
             } catch(Exception ee) {
                 throw ee;
@@ -434,12 +468,32 @@ class Action3DData {
         DocumentBuilder db = dbf.newDocumentBuilder();
         Document d = null;
         try {
-            d = db.parse("x-rzip:"+url.toString()+"!/CATALOG.XML");
-//            d = db.parse("jar:"+url.toString()+"!/CATALOG.XML");
+            String cURL = null;
+            if (url.getProtocol().equals("file")) {
+                File f = new File(url.toURI());
+                if (f.isDirectory()) {
+                    cURL = url.toString() + "/CATALOG.XML";
+                } else {
+                    cURL = "x-rzip:"+url.toString()+"!/CATALOG.XML";
+                }
+            } else {
+                cURL = "x-rzip:"+url.toString()+"!/CATALOG.XML";
+            }
+            d = db.parse(cURL);
         } catch(Exception e) {
             try {
-                d = db.parse("x-rzip:"+url.toString()+"!/catalog.xml");
-//                d = db.parse("jar:"+url.toString()+"!/catalog.xml");
+                String cURL = null;
+                if (url.getProtocol().equals("file")) {
+                    File f = new File(url.toURI());
+                    if (f.isDirectory()) {
+                        cURL = url.toString() + "/catalog.xml";
+                    } else {
+                        cURL = "x-rzip:"+url.toString()+"!/catalog.xml";
+                    }
+                } else {
+                    cURL = "x-rzip:"+url.toString()+"!/catalog.xml";
+                }
+                d = db.parse(cURL);
             } catch (Exception ee) {
                 throw ee;
             }
@@ -606,28 +660,47 @@ class Action3DData {
         HashSet<Part> s = new HashSet<Part>();
         for (int i=0;i<actions.length;i++)
             s.addAll(actions[i].pHash.values());
-        shapes = new HashMap<String,SharedGroup>();
+        shapes = new HashMap<String,ShapeAndBF>();
         for (Part p : s) {
-            URL wrlURL = new URL("x-rzip:"+url.toString()+"!/"+p.fileName);
-            SharedGroup sg = new SharedGroup();
+            URL wrlURL = null;
+            if (url.getProtocol().equals("file")) {
+                File f = new File(url.toURI());
+                if (f.isDirectory()) {
+                    wrlURL = new URL(url.toString()+"/"+p.fileName);
+                } else {
+                    wrlURL = new URL("x-rzip:"+url.toString()+"!/"+p.fileName);
+                }
+            } else {
+                wrlURL = new URL("x-rzip:"+url.toString()+"!/"+p.fileName);
+            }
+            ShapeAndBF shapeAndBF = new ShapeAndBF();
+            shapeAndBF.sg = new SharedGroup();
             Transform3D t = new Transform3D();
             //このにp.scale,offset,rotの処理を書く
             TransformGroup tg = new TransformGroup(t);
             Scene scene = loader.load(wrlURL);
-            //以下背景と霧を読み込むためのハックなのだが、
-            //SharedGroupには追加できないのでだめだった。
-            //Background[] bs = scene.getBackgroundNodes();
-            //for (int i=0;i<bs.length;i++)
-            //    tg.addChild(bs[i].cloneNode(false));
-            //Fog fogs[] = scene.getFogNodes();
-            //for (int i=0;i<fogs.length;i++)
-            //    tg.addChild(fogs[i].cloneNode(false));
             tg.addChild(scene.getSceneGroup());
-            sg.addChild(tg);
+            shapeAndBF.sg.addChild(tg);
+            shapeAndBF.b = scene.getBackgroundNodes(); 
+            //Background bs[] = scene.getBackgroundNodes(); 
+            //shapeAndBF.b = new Background[bs.length];
+            //for (int i=0;i<bs.length;i++)
+            //    shapeAndBF.b[i] = (Background)bs[i].cloneNode(false);
+            shapeAndBF.f = scene.getFogNodes();
+            //Fog fogs[] = scene.getFogNodes();
+            //shapeAndBF.f = new Fog[fogs.length];
+            //for (int i=0;i<fogs.length;i++)
+            //    shapeAndBF.f[i] = (Fog)fogs[i].cloneNode(false);
             //sg.compile();
-            shapes.put(p.fileName,sg);
+            shapes.put(p.fileName,shapeAndBF);
         }
     }
+    //通常のオブジェクトと背景、霧をまとめた物
+    class ShapeAndBF {
+        SharedGroup sg;
+        Background b[];
+        Fog f[];
+    }
 
     void loadAllMotions() throws Exception {
         HashSet<String> s = new HashSet<String>();
@@ -636,7 +709,17 @@ class Action3DData {
                 s.add(actions[i].bvhFile);
         motions = new HashMap<String,Motion>();
         for (String filename : s) {
-            URL motionURL = new URL("x-rzip:"+url.toString()+"!/"+filename);
+            URL motionURL = null;
+            if (url.getProtocol().equals("file")) {
+                File f = new File(url.toURI());
+                if (f.isDirectory()) {
+                    motionURL = new URL(url.toString()+"/"+filename);
+                } else {
+                    motionURL = new URL("x-rzip:"+url.toString()+"!/"+filename);
+                }
+            } else {
+                motionURL = new URL("x-rzip:"+url.toString()+"!/"+filename);
+            }
             BVH bvh = new BVH(motionURL);
             motions.put(filename,bvh);
         }
@@ -649,7 +732,17 @@ class Action3DData {
                 s.add(actions[i].soundFile);
         sounds = new HashMap<String,MediaContainer>();
         for (String filename : s) {
-            URL soundURL = new URL("x-rzip:"+url.toString()+"!/"+filename);
+            URL soundURL = null;
+            if (url.getProtocol().equals("file")) {
+                File f = new File(url.toURI());
+                if (f.isDirectory()) {
+                    soundURL = new URL(url.toString()+"/"+filename);
+                } else {
+                    soundURL = new URL("x-rzip:"+url.toString()+"!/"+filename);
+                }
+            } else {
+                soundURL = new URL("x-rzip:"+url.toString()+"!/"+filename);
+            }
             MediaContainer mc = new MediaContainer(soundURL);
             sounds.put(filename,mc);
         }
