@@ -11,7 +11,7 @@ import javax.vecmath.*;
  * このクラスで全て受け持つことにする。
  */
 class ActionBehavior extends Behavior implements Cloneable {
-    static BoundingSphere bounding = new BoundingSphere(new Point3d(0.0,0.0,0.0),100.0);
+    static BoundingSphere bounding = new BoundingSphere(new Point3d(0.0,0.0,0.0),Double.MAX_VALUE);
     //  現在のアクションNO
     int actionNo = 0;
     boolean immediatelyFlag = false;
@@ -48,13 +48,14 @@ class ActionBehavior extends Behavior implements Cloneable {
     }
     void init() {
         synchronized (actionQueue) {
-            //gaha;
-            actionNo = actionQueue.remove(0);
-            //a3Data.allActionSwitch.setWhichChild(actionNo);
-            Node n = a3Data.actions[actionNo].getRootGroup();
-            a3Data.allActionBranchGroup.removeAllChildren();
-            a3Data.allActionBranchGroup.addChild(n);
-            a3Data.actions[actionNo].start();
+            if (actionQueue.size()>0) {
+                actionNo = actionQueue.remove(0);
+                //a3Data.allActionSwitch.setWhichChild(actionNo);
+                Node n = a3Data.actions[actionNo].getRootGroup();
+                a3Data.allActionBranchGroup.removeAllChildren();
+                a3Data.allActionBranchGroup.addChild(n);
+                a3Data.actions[actionNo].start();
+            }
         }
     }
     public void initialize() {
