@@ -1,6 +1,7 @@
 package jp.sourceforge.acerola3d.a3;
 
 import java.awt.event.*;
+
 import javax.vecmath.*;
 
 /**
@@ -63,6 +64,7 @@ System.out.println(a3canvas.getCameraLoc());
             if ((me.getModifiers()&MouseEvent.SHIFT_MASK)==0) {
                 Tuple3d shift = a3canvas.canvasToVirtualCS(lastMouseX,lastMouseY,distance); 
                 shift.sub(a3canvas.canvasToVirtualCS(me.getX(),me.getY(),distance));
+                shift.scale(1.0/a3canvas.getCameraScale());
                 fixationPoint.add(shift);
             } else {
                 Tuple3d shift = a3canvas.canvasToPhysicalCS(lastMouseX,lastMouseY,distance); 
@@ -70,6 +72,7 @@ System.out.println(a3canvas.getCameraLoc());
                 shift.z = - shift.y;
                 shift.y = 0.0;
                 shift = a3canvas.physicalCSToVirtualCS(new Vector3d(shift));
+                shift.scale(1.0/a3canvas.getCameraScale());
                 fixationPoint.add(shift);
             }
         } else if ((me.getModifiersEx()&MouseEvent.BUTTON3_DOWN_MASK)!=0) {
@@ -92,7 +95,7 @@ System.out.println(a3canvas.getCameraLoc());
         tmpV.set(tmpV.x+tmpQ.x,tmpV.y+tmpQ.y,tmpV.z+tmpQ.z);
         a3canvas.setCameraLocImmediately(tmpV);
         a3canvas.setCameraQuatImmediately(cameraQuat);
-        a3canvas.setCameraScaleImmediately(distance/2.0);//2009,08/14追加
+        a3canvas.setCameraScaleImmediately(distance/3.0);
     }
 
     /**
